//
//  GraphPlotLine.m
//  Grraphs
//
//  Created by Pedro Sousa on 7/20/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "GraphPlotLine.h"

@interface GraphPlotLine ()

@property (nonatomic , strong)NSMutableArray *arrValuesX;
@property (nonatomic , strong)NSMutableArray *arrValuesY;
@property (nonatomic , strong)NSMutableArray *arrLabels;

@end

@implementation GraphPlotLine

@synthesize arrLabels = _arrLabels;
@synthesize arrValuesX = _arrValuesX;
@synthesize arrValuesY = _arrValuesY;

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        // Initialization code
    }
    return self;
}

-(void)setFontSize:(float)value
{
    fontSize = value;
}
-(void)setStartPosYGraphic:(float)value
{
    startPosYGraphic = value;
}
-(void)setTopValueY:(float)value
{
    topValueY = value;
}
-(void)setTopValueX:(float)value
{
    topValueX = value;
}

-(void)setTopGrapfSizeY:(float)value
{
    grapfSizeY = value;
}
-(void)setTopGrapfSizeX:(float)value
{
    grapfSizeX = value;
}

-(void)addValue:(float)valueX valueY:(float)valueY label:(NSString*)label
{
     
    float formatY = (grapfSizeY * valueY) / topValueY;
    float yTo = startPosYGraphic - formatY;
    float xTo =  (grapfSizeX * valueX) / topValueX;

    
    [self.arrLabels addObject:label];
    [self.arrValuesX addObject:[NSNumber numberWithFloat:xTo]];
    [self.arrValuesY addObject:[NSNumber numberWithFloat:yTo]];
}


-(void)drawRect:(CGRect)rect
{
	[self drawInContext:UIGraphicsGetCurrentContext()];
}

-(void)drawInContext:(CGContextRef)context
{
    
    int len = [self.arrLabels count];
    
    for(int i = 0 ; i < len;i++)
    {
        NSString *label = [self.arrLabels objectAtIndex:i];
        float x = [(NSNumber *)[self.arrValuesX objectAtIndex:i] floatValue];
        float y = [(NSNumber *)[self.arrValuesY objectAtIndex:i] floatValue];
        
        
        [self createLine:context xValue:x yValue:y label:label];
        
    }
    
    for(int i = 0 ; i < len;i++)
    {
        NSString *label = [self.arrLabels objectAtIndex:i];
        float x = [(NSNumber *)[self.arrValuesX objectAtIndex:i] floatValue];
        float y = [(NSNumber *)[self.arrValuesY objectAtIndex:i] floatValue];
        
        
        [self createSpheresAndLabel:context xValue:x yValue:y label:label];
        
    }
    
}

-(void)createLine:(CGContextRef)context xValue:(float)xValue yValue:(float)yValue label:(NSString *)label
{    
    
   
    
    
    CGContextSetLineWidth(context, 2.0);
    
    CGColorSpaceRef colorspace = CGColorSpaceCreateDeviceRGB();
    
    CGFloat components[] = {0.0, 0.0, 1.0, 1.0};
    CGColorRef color = CGColorCreate(colorspace, components);
    CGContextSetStrokeColorWithColor(context, color);
    
    CGContextMoveToPoint(context, lastX, lastY);
    CGContextAddLineToPoint(context, xValue, yValue);
    
    CGContextStrokePath(context);
    CGColorSpaceRelease(colorspace);
    CGColorRelease(color);
    
    lastX = xValue;
    lastY = yValue;
}

-(void)createSpheresAndLabel:(CGContextRef)context xValue:(float)xValue yValue:(float)yValue label:(NSString *)label
{
    CGContextSelectFont (context, "Verdana",fontSize,kCGEncodingMacRoman);
    CGContextSetCharacterSpacing (context, 2);
    CGContextSetTextDrawingMode (context, kCGTextFillStroke);
    
    CGColorSpaceRef colorspace = CGColorSpaceCreateDeviceRGB();
    CGFloat components[] = {0.0, 0.0, 1.0, 1.0};
    
    CGColorRef color = CGColorCreate(colorspace, components);
    
    CGFloat componentsBlack[] = {0.0, 0.0, 0.0, 1.0};
    color = CGColorCreate(colorspace, componentsBlack);
    CGContextSetStrokeColorWithColor(context, color);
    
    float wordSize = label.length * 5;
    
    CGContextSetAllowsAntialiasing(context, YES);
    CGContextSetTextMatrix(context, CGAffineTransformMake(1.0,0.0, 0.0, -1.0, 0.0, 0.0));
    CGContextShowTextAtPoint (context, xValue - (wordSize / 2), yValue - 10,[label UTF8String] , label.length);  
    
    
    //Cricle pointer
    
    CGContextSetStrokeColorWithColor(context, [UIColor blackColor].CGColor);
    CGContextSetRGBFillColor (context, 1, 0, 0, 1); 
    CGRect rectangle = CGRectMake(xValue - 4.0f,yValue - 4.0f,8,8);    
    
    CGContextFillEllipseInRect(context, rectangle);
    
    CGContextAddEllipseInRect(context, rectangle);
    CGContextStrokePath(context);
    
    lastX = xValue;
    lastY = yValue;
}



-(void)reload
{
    lastX = 0;
    lastY = startPosYGraphic;
    
    [self setNeedsDisplay];
}
-(void)clear
{
    self.arrValuesX = [[NSMutableArray alloc]init];
    self.arrValuesY = [[NSMutableArray alloc]init];
    self.arrLabels = [[NSMutableArray alloc]init];
}



@end
